<?php
/**
 * Migration
 *
 * @package Page Builder Framework Migration
 */
 
// exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

function wpbf_migration_after() {

	// if image logo exists, update custom_logo
	if ( get_theme_mod( 'menu_logo' ) ) {

		// retrieves the attachment ID from the logo URL
		function wpbf_get_image_id( $image_url ) {
			global $wpdb;
			$attachment = $wpdb->get_col( $wpdb->prepare( "SELECT ID FROM $wpdb->posts WHERE guid='%s';", $image_url ) ); 
		        return $attachment[0]; 
		}

		// get id of the logo
		$logo_url = esc_url( get_theme_mod( 'menu_logo' ) );
		$logo_id = (int) wpbf_get_image_id( $logo_url );

		// set the logo id for the custom_logo theme mod & clean up behind us
		set_theme_mod( 'custom_logo', $logo_id );

	}

	// if a text logo existed, update blogname
	if ( get_theme_mod( 'menu_logo_text' ) ) {

		// update blogname and clean up behind us
		$blog_name = esc_html( get_theme_mod( 'menu_logo_text' ) );
		update_option( 'blogname', $blog_name );

	}

	// if a background image has been set, update background_image
	if ( get_theme_mod( 'page_background_image' ) ) {

		$background_image = esc_url( get_theme_mod( 'page_background_image' ) );

		// update background image and clean up behind us
		set_theme_mod( 'background_image', $background_image );

	}

	// if a background color has been set, update background_color
	if ( get_theme_mod( 'page_background_color' ) ) {

		$background_color = esc_attr( get_theme_mod( 'page_background_color' ) );
		$background_color = str_replace( '#', '', $background_color );

		// update background color and clean up behind us
		set_theme_mod( 'background_color', $background_color );

	}

}

function wbpf_migration_after_hard() {
	remove_theme_mod( 'menu_logo' );
	remove_theme_mod( 'menu_logo_text' );
	remove_theme_mod( 'page_background_image' );
	remove_theme_mod( 'page_background_color' );
}

// Migration
if( is_multisite() && !is_main_site() ) {

	$migration_settings = get_blog_option( 1, 'wpbf_migration_settings' );

} else {

	$migration_settings = get_option( 'wpbf_migration_settings' );

}

// delete old transient
delete_transient( 'no_file' );

// Hard Migration
if( isset( $migration_settings['wpbfm-hard-migration'] ) ) {

	if( $migration_settings['wpbfm-from-select'] == 'child-theme' ) {
		wpbf_migration_after();
		wbpf_migration_after_hard();
		if( get_option( 'template' ) && get_option( 'template' ) == 'wpbf' ) {
			update_option( 'template', 'page-builder-framework' );
		}
	} elseif( $migration_settings['wpbfm-from-select'] == 'main-theme' ) {
		if( get_option( 'theme_mods_wpbf' ) ) {
			update_option( 'theme_mods_page-builder-framework', get_option( 'theme_mods_wpbf' ) );
			wpbf_migration_after();
			wbpf_migration_after_hard();
			delete_option( 'theme_mods_wpbf' );
		}
	}

// Soft Migration
} elseif( isset( $migration_settings['wpbfm-soft-migration'] ) ) {

	if( $migration_settings['wpbfm-from-select'] == 'child-theme' ) {
		wpbf_migration_after();
		if( get_option( 'template' ) && get_option( 'template' ) == 'wpbf' ) {
			update_option( 'template', 'page-builder-framework' );
		}
	} elseif( $migration_settings['wpbfm-from-select'] == 'main-theme' ) {
		if( get_option( 'theme_mods_wpbf' ) ) {
			update_option( 'theme_mods_page-builder-framework', get_option( 'theme_mods_wpbf' ) );
			wpbf_migration_after();
		}
	}
}