<?php
/**
 * Settings
 *
 * @package Page Builder Framework Migration
 */
 
// exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

// Settings
add_action( 'admin_init', 'wpbf_migration_function' );

function wpbf_migration_function() {

	// Register Settings
	register_setting( 'wpbf-migration-group', 'wpbf_migration_settings' );

	// Settings Sections
	add_settings_section( 'wpbfm-migration-settings', '', 'wpbfm_migration_settings_callback', 'wpbf-migration-settings' );

	// Settings Fields
	add_settings_field( 'wpbfm-from-select', 'Child Theme', 'wpbfm_from_callback', 'wpbf-migration-settings', 'wpbfm-migration-settings' );
	// add_settings_field( 'wpbfm-custom-theme-folder', 'Custom Child Theme Folder Name', 'wpbfm_custom_theme_folder_callback', 'wpbf-migration-settings', 'wpbfm-migration-settings' );
	add_settings_field( 'wpbfm-soft-migration', 'Soft Migration', 'wpbfm_soft_migration_fallback', 'wpbf-migration-settings', 'wpbfm-migration-settings' );
	add_settings_field( 'wpbfm-hard-migration', 'Hard Migration', 'wpbfm_hard_migration_fallback', 'wpbf-migration-settings', 'wpbfm-migration-settings' );

}

function wpbfm_hard_migration_fallback() {
	$wpbf_migration_settings = get_option( 'wpbf_migration_settings' );

	if ( !isset( $wpbf_migration_settings['wpbfm-hard-migration'] ) ) {
		$hard_migration = false;
	} else {
		$hard_migration = 'hard_migration';
	}

	echo '<label><input type="checkbox" name="wpbf_migration_settings[wpbfm-hard-migration]" value="hard_migration" '. checked( $hard_migration, "hard_migration", false ) .' />Activate<p class="description"><span style="color:tomato;">This will remove old theme related data from your database.</span><br>Only run this option after soft migration was successful!</p></label>';
}


function wpbfm_soft_migration_fallback() {
	$wpbf_migration_settings = get_option( 'wpbf_migration_settings' );

	if ( !isset( $wpbf_migration_settings['wpbfm-soft-migration'] ) ) {
		$soft_migration = false;
	} else {
		$soft_migration = 'soft_migration';
	}

	echo '<label><input type="checkbox" name="wpbf_migration_settings[wpbfm-soft-migration]" value="soft_migration" '. checked( $soft_migration, "soft_migration", false ) .' />Activate<p class="description">This will leave your old theme related data in the database.<br>You can always switch back for troubleshooting. To roll back, switch to a random theme and re-activate Page Builder Framework or child theme.</p></label>';
}

function wpbfm_migration_settings_callback() {
	echo '<p class="description">This tool lets you migrate from Page Builder Framework at https://wp-pagebuilderframework.com to the theme available in the WordPress repository. <br> <span style="color: tomato;">Make sure you back up your <strong>database</strong> before running this tool. These changes are irreversible!</span></p>';
}

function wpbfm_from_callback() {

	$wpbf_migration_settings = get_option( 'wpbf_migration_settings' );

	if ( !isset( $wpbf_migration_settings['wpbfm-from-select'] ) ) {

		$from = 'select';


	} else {

		$from = $wpbf_migration_settings['wpbfm-from-select'];

	}

	?>

	<select id="wpbfm-from-select" name="wpbf_migration_settings[wpbfm-from-select]">
		<option value="select" <?php selected( $from, 'select', true ); ?>>Select</option>
		<option value="main-theme" <?php selected( $from, 'main-theme', true ); ?>>No, I'm not using a child theme</option>
		<option value="child-theme" <?php selected( $from, 'child-theme', true ); ?>>Yes, I'm using a child theme</option>
	</select>
	<p class="description">Select if you are currently using a child theme with Page Builder Framework</p>
<?php }

function wpbfm_custom_theme_folder_callback() {

	$wpbf_migration_settings = get_option( 'wpbf_migration_settings' );

	if ( !isset( $wpbf_migration_settings['wpbfm-custom-theme-folder'] ) ) {

		$theme_name = false;

	} else {

		$theme_name = $wpbf_migration_settings['wpbfm-custom-theme-folder'];

	}

	echo '<input type="text" name="wpbf_migration_settings[wpbfm-custom-theme-folder]" placeholder="eg: my-custom-theme" value="'. esc_html( $theme_name ) .'" />';
	echo '<p class="description">Folder name of your custom child theme.<br><span style="color: tomato;">Leave blank if you were not using a custom child theme.</span></p>';

}